# eric7.Plugins.VcsPlugins.vcsMercurial.GpgExtension

Package implementing the gpg extension support interface.

### Modules

HgGpgSignDialog | Module implementing a dialog to enter data for signing a revision.
HgGpgSignaturesDialog | Module implementing a dialog showing signed changesets.
ProjectHelper | Module implementing the gpg extension project helper.
gpg | Module implementing the gpg extension interface.